Welcome to Credit Risk Toolbox's documentation!
========================================================

.. toctree::
   :maxdepth: 2
   :caption: Overview

   introduction
   tests
   contributing
   usage
   
   
.. toctree::
   :maxdepth: 2
   :caption: Functions and classes

   meliora/meliora

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
